@@ -1,8 +1,9 @@
 # R/globals.R
 
 utils::globalVariables(c(
-  ".", ":=", "Chain", "Pred_for_missing", "Pred_for_observeds", "True_distance",
+  ".", ":=", "Chain", "Pred_for_missing", "Pred_for_observed", "True_distance",
   "X", "X.1", "cluster", "color", "count", "distance", "euclidean_dist",
   "mag", "max_value", "n", "name", "processed_value", "sample1", "sample2",
-  "season", "season_num", "total_count", "year"
+  "season", "season_num", "total_count", "year", "final_value", 
+  "True_dissimilarity", "Pred_for_observed"
 ))
\ No newline at end of file
